"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const prompts_1 = require("@inquirer/prompts");
const schema_command_1 = tslib_1.__importDefault(require("../../lib/schema-command"));
const color_1 = require("../../lib/color");
class CommitSchemaCommand extends schema_command_1.default {
    async run() {
        var _a, _b, _c;
        try {
            const { url, secret } = await this.fetchsetup();
            if ((_a = this.flags) === null || _a === void 0 ? void 0 : _a["no-input"]) {
                const params = new URLSearchParams({
                    force: "true", // Just commit, don't pass a schema version through.
                });
                const path = new URL(`/schema/1/staged/commit?${params}`, url);
                const res = await fetch(path, {
                    method: "POST",
                    headers: { AUTHORIZATION: `Bearer ${secret}` },
                    // https://github.com/nodejs/node/issues/46221
                    // https://github.com/microsoft/TypeScript-DOM-lib-generator/issues/1483
                    // @ts-expect-error-next-line
                    duplex: "half",
                });
                const json = await res.json();
                if (json.error) {
                    this.error((_c = (_b = json.error) === null || _b === void 0 ? void 0 : _b.message) !== null && _c !== void 0 ? _c : json.error);
                }
                this.log("Schema has been committed");
            }
            else {
                // Show status to confirm.
                const params = new URLSearchParams({
                    ...((0, color_1.hasColor)() ? { color: (0, color_1.colorParam)() } : {}),
                    diff: "true",
                });
                const res = await fetch(new URL(`/schema/1/staged/status?${params}`, url), {
                    method: "GET",
                    headers: { AUTHORIZATION: `Bearer ${secret}` },
                    // @ts-expect-error-next-line
                    duplex: "half",
                });
                const json = await res.json();
                if (json.error) {
                    this.error(json.error.message);
                }
                if (json.status === "none") {
                    this.error("There is no staged schema to commit");
                }
                this.log(json.diff);
                if (json.status !== "ready") {
                    this.error("Schema is not ready to be committed");
                }
                const confirmed = await (0, prompts_1.confirm)({
                    message: "Accept and commit these changes?",
                    default: false,
                });
                if (confirmed) {
                    const params = new URLSearchParams({ version: json.version });
                    const path = new URL(`/schema/1/staged/commit?${params}`, url);
                    const res = await fetch(path, {
                        method: "POST",
                        headers: { AUTHORIZATION: `Bearer ${secret}` },
                        // @ts-expect-error-next-line
                        duplex: "half",
                    });
                    const json0 = await res.json();
                    if (json0.error) {
                        this.error(json0.error.message);
                    }
                    this.log("Schema has been committed");
                }
                else {
                    this.log("Commit cancelled");
                }
            }
        }
        catch (err) {
            this.error(err);
        }
    }
}
CommitSchemaCommand.flags = {
    ...schema_command_1.default.flags,
};
CommitSchemaCommand.description = "Commits the currently staged schema.";
CommitSchemaCommand.examples = ["$ fauna schema commit"];
exports.default = CommitSchemaCommand;
