"use strict";
// TODO: Remove all this stuff.
Object.defineProperty(exports, "__esModule", { value: true });
exports.readFile = readFile;
exports.writeFile = writeFile;
exports.runQueries = runQueries;
const vm_1 = require("vm");
const fs_1 = require("fs");
const faunadb_1 = require("faunadb");
const escodegen_1 = require("escodegen");
/**
 * Wraps `fs.readFile` into a Promise.
 */
function readFile(fileName) {
    return new Promise((resolve, reject) => {
        (0, fs_1.readFile)(fileName, "utf8", (err, data) => {
            // this lint is dumb
            // eslint-disable-next-line no-unused-expressions
            err ? reject(err) : resolve(data);
        });
    });
}
/**
 * Wraps `fs.writeFile` into a Promise.
 */
function writeFile(fileName, data, mode) {
    return new Promise((resolve, reject) => {
        (0, fs_1.writeFile)(fileName, data, { mode: mode }, (err) => {
            // this lint is dumb
            // eslint-disable-next-line no-unused-expressions
            err ? reject(err) : resolve(data);
        });
    });
}
// adapted from https://hackernoon.com/functional-javascript-resolving-promises-sequentially-7aac18c4431e
function promiseSerial(fs) {
    return fs.reduce((promise, f) => promise.then((result) => f().then(Array.prototype.concat.bind(result))), Promise.resolve([]));
}
class QueryError extends Error {
    constructor(exp, faunaError, queryNumber, ...params) {
        super(params);
        if (Error.captureStackTrace) {
            Error.captureStackTrace(this, QueryError);
        }
        this.exp = exp;
        this.faunaError = faunaError;
        this.queryNumber = queryNumber;
    }
}
function wrapQueries(expressions, client) {
    const q = faunadb_1.query;
    (0, vm_1.createContext)(q);
    return expressions.map((exp, queryNumber) => () => {
        let query;
        try {
            query = (0, vm_1.runInContext)((0, escodegen_1.generate)(exp), q);
        }
        catch (e) {
            return Promise.reject(e);
        }
        return client.query(query).catch((err) => {
            throw new QueryError((0, escodegen_1.generate)(exp), err, queryNumber + 1);
        });
    });
}
async function runQueries(expressions, client) {
    if (expressions.length === 1) {
        var f = wrapQueries(expressions, client)[0];
        return f();
    }
    else {
        return promiseSerial(wrapQueries(expressions, client));
    }
}
